@@ -3,12 +3,12 @@
     <name>defaultlook</name>
     <message>
         <location filename="defaultlook.ui" line="20"/>
-        <location filename="defaultlook.cpp" line="55"/>
-        <location filename="defaultlook.cpp" line="467"/>
-        <location filename="defaultlook.cpp" line="474"/>
-        <location filename="defaultlook.cpp" line="491"/>
+        <location filename="defaultlook.cpp" line="58"/>
         <location filename="defaultlook.cpp" line="502"/>
-        <location filename="defaultlook.cpp" line="512"/>
+        <location filename="defaultlook.cpp" line="509"/>
+        <location filename="defaultlook.cpp" line="526"/>
+        <location filename="defaultlook.cpp" line="537"/>
+        <location filename="defaultlook.cpp" line="547"/>
         <source>MX Tweak</source>
         <translation type="unfinished"/>
     </message>
@@ -56,7 +56,7 @@
     <message>
         <location filename="defaultlook.ui" line="234"/>
         <source>Help</source>
-        <translation type="unfinished"/>
+        <translation>Abi</translation>
     </message>
     <message>
         <location filename="defaultlook.ui" line="251"/>
@@ -66,7 +66,7 @@
     <message>
         <location filename="defaultlook.ui" line="254"/>
         <source>Close</source>
-        <translation type="unfinished"/>
+        <translation>Sulge</translation>
     </message>
     <message>
         <location filename="defaultlook.ui" line="261"/>
@@ -141,9 +141,9 @@
     <message>
         <location filename="defaultlook.ui" line="446"/>
         <location filename="defaultlook.ui" line="549"/>
-        <location filename="defaultlook.ui" line="741"/>
-        <location filename="defaultlook.ui" line="860"/>
-        <location filename="defaultlook.ui" line="902"/>
+        <location filename="defaultlook.ui" line="740"/>
+        <location filename="defaultlook.ui" line="894"/>
+        <location filename="defaultlook.ui" line="936"/>
         <source>Apply</source>
         <translation type="unfinished"/>
     </message>
@@ -184,7 +184,7 @@
     </message>
     <message>
         <location filename="defaultlook.ui" line="589"/>
-        <source>Remove User Theme Sets</source>
+        <source>Remove User Theme Set</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -194,203 +194,233 @@
     </message>
     <message>
         <location filename="defaultlook.ui" line="614"/>
-        <location filename="defaultlook.ui" line="707"/>
+        <location filename="defaultlook.ui" line="760"/>
         <source>Compositor</source>
         <translation type="unfinished"/>
     </message>
     <message>
         <location filename="defaultlook.ui" line="635"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="638"/>
-        <source>Xfwm Settings</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="662"/>
-        <source>None</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="667"/>
-        <source>Xfwm (Xfce) Compositor</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="672"/>
-        <source>Compton </source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="680"/>
-        <source>Edit compton.conf directly in text editor</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="683"/>
-        <source>Edit compton.conf</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="714"/>
-        <source>Transparency and shadow options</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="defaultlook.ui" line="721"/>
         <source>Launch compton-conf configuration tool</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="724"/>
+        <location filename="defaultlook.ui" line="638"/>
         <source>Compton settings</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <location filename="defaultlook.ui" line="662"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="665"/>
+        <source>Xfwm Settings</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="689"/>
+        <source>None</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="694"/>
+        <source>Xfwm (Xfce) Compositor</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="699"/>
+        <source>Compton </source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="707"/>
+        <source>Edit compton.conf directly in text editor</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="710"/>
+        <source>Edit compton.conf</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="767"/>
+        <source>Transparency and shadow options</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="774"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"/>
+    </message>
     <message>
         <location filename="defaultlook.ui" line="777"/>
-        <source>Config Options</source>
+        <source>VBlank</source>
         <translation type="unfinished"/>
     </message>
     <message>
         <location filename="defaultlook.ui" line="785"/>
+        <source>auto</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="790"/>
+        <source>glx</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="795"/>
+        <source>xpresent</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="800"/>
+        <source>off</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="811"/>
+        <source>Config Options</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="defaultlook.ui" line="819"/>
         <source>Reset Lightdm (login screen) to system default theme</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="792"/>
+        <location filename="defaultlook.ui" line="826"/>
         <source>Reset Thunar custom right-click actions to system defaults</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="799"/>
+        <location filename="defaultlook.ui" line="833"/>
         <source>Use intel driver instead of default &quot;modsetting&quot; driver (requires restart)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="806"/>
+        <location filename="defaultlook.ui" line="840"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="813"/>
+        <location filename="defaultlook.ui" line="847"/>
         <source>Use tearfree amdgpu option</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="820"/>
+        <location filename="defaultlook.ui" line="854"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="827"/>
+        <location filename="defaultlook.ui" line="861"/>
         <source>Use tearfree radeon driver option</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="834"/>
+        <location filename="defaultlook.ui" line="868"/>
         <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="874"/>
+        <location filename="defaultlook.ui" line="908"/>
         <source>Other</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="882"/>
+        <location filename="defaultlook.ui" line="916"/>
         <source>Enable single-click on desktop</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="889"/>
+        <location filename="defaultlook.ui" line="923"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="926"/>
+        <location filename="defaultlook.ui" line="960"/>
         <source>Show systray (notification area) frame</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="933"/>
+        <location filename="defaultlook.ui" line="967"/>
         <source>Show windows from all workspaces in panel</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="940"/>
+        <location filename="defaultlook.ui" line="974"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="947"/>
+        <location filename="defaultlook.ui" line="981"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="954"/>
+        <location filename="defaultlook.ui" line="988"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.ui" line="961"/>
+        <location filename="defaultlook.ui" line="995"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="466"/>
+        <location filename="defaultlook.cpp" line="501"/>
         <source>About MX Tweak</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="467"/>
+        <location filename="defaultlook.cpp" line="502"/>
         <source>Version: </source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="468"/>
+        <location filename="defaultlook.cpp" line="503"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="470"/>
+        <location filename="defaultlook.cpp" line="505"/>
         <source>Copyright (c) MX Linux</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="471"/>
-        <location filename="defaultlook.cpp" line="474"/>
+        <location filename="defaultlook.cpp" line="506"/>
+        <location filename="defaultlook.cpp" line="509"/>
         <source>License</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="472"/>
+        <location filename="defaultlook.cpp" line="507"/>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Loobu</translation>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="503"/>
+        <location filename="defaultlook.cpp" line="538"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="513"/>
+        <location filename="defaultlook.cpp" line="548"/>
         <source>This app is Xfce-only</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="655"/>
+        <location filename="defaultlook.cpp" line="690"/>
         <source>Panel settings</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="656"/>
+        <location filename="defaultlook.cpp" line="691"/>
         <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
         <translation type="unfinished"/>
     </message>
     <message>
-        <location filename="defaultlook.cpp" line="1073"/>
+        <location filename="defaultlook.cpp" line="1117"/>
         <source>Choose a theme set</source>
         <translation type="unfinished"/>
     </message>
@@ -407,7 +437,7 @@
     <name>theming_to_tweak</name>
     <message>
         <location filename="theming_to_tweak.ui" line="14"/>
-        <source>Dialog</source>
+        <source>New Theme Set</source>
         <translation type="unfinished"/>
     </message>
     <message>
@@ -420,7 +450,7 @@
     <name>window_buttons</name>
     <message>
         <location filename="window_buttons.ui" line="14"/>
-        <location filename="window_buttons.cpp" line="36"/>
+        <location filename="window_buttons.cpp" line="37"/>
         <source>Window Buttons</source>
         <translation type="unfinished"/>
     </message>
@@ -630,10 +660,10 @@
     <message>
         <location filename="xfwm_compositor_settings.ui" line="212"/>
         <source>Close</source>
-        <translation type="unfinished"/>
+        <translation>Sulge</translation>
     </message>
     <message>
-        <location filename="xfwm_compositor_settings.cpp" line="38"/>
+        <location filename="xfwm_compositor_settings.cpp" line="39"/>
         <source>Xfwm Compositor Settings</source>
         <translation type="unfinished"/>
     </message>
